@@ -26,7 +26,6 @@
 #include <QSlider>
 #include <QVBoxLayout>
 
-#include <KAboutData>
 #include <KConfigDialogManager>
 #include <KConfigGroup>
 #include <KConfigSkeleton>
@@ -80,7 +79,7 @@ KAudiocdModule::KAudiocdModule(QObject *parent, const KPluginMetaData &md)
     connect(audioConfig->fileNameLineEdit, &QLineEdit::textEdited, this, &KAudiocdModule::slotConfigChanged);
     connect(audioConfig->albumNameLineEdit, &QLineEdit::textEdited, this, &KAudiocdModule::slotConfigChanged);
     connect(audioConfig->fileLocationLineEdit, &QLineEdit::textEdited, this, &KAudiocdModule::slotConfigChanged);
-    connect(audioConfig->fileLocationGroupBox, &QGroupBox::clicked, this, &KAudiocdModule::slotConfigChanged);
+    connect(audioConfig->fileLocationCheckBox, &QCheckBox::clicked, this, &KAudiocdModule::slotConfigChanged);
     connect(audioConfig->kcfg_replaceInput, &QLineEdit::textEdited, this, &KAudiocdModule::updateExample);
     connect(audioConfig->kcfg_replaceOutput, &QLineEdit::textEdited, this, &KAudiocdModule::updateExample);
     connect(audioConfig->example, &QLineEdit::textEdited, this, &KAudiocdModule::updateExample);
@@ -158,9 +157,14 @@ void KAudiocdModule::save()
         KConfigGroup cg(config, QStringLiteral("FileName"));
         cg.writeEntry("file_name_template", audioConfig->fileNameLineEdit->text());
         cg.writeEntry("album_name_template", audioConfig->albumNameLineEdit->text());
-        cg.writeEntry("show_file_location", audioConfig->fileLocationGroupBox->isChecked());
-        cg.writeEntry("file_location_template", audioConfig->fileLocationLineEdit->text());
+        cg.writeEntry("show_file_location", audioConfig->fileLocationCheckBox->isChecked());
         cg.writeEntry("regexp_example", audioConfig->example->text());
+        QString location = audioConfig->fileLocationLineEdit->text();
+        // ensure FileLocation doesn't end with '/'
+        while (location.endsWith(QLatin1Char('/'))) {
+            location.chop(1);
+        }
+        cg.writeEntry("file_location_template", location);
 
         // save quoted if required
         QString replaceInput = audioConfig->kcfg_replaceInput->text();
@@ -198,7 +202,7 @@ void KAudiocdModule::load()
         KConfigGroup cg(config, QStringLiteral("FileName"));
         audioConfig->fileNameLineEdit->setText(cg.readEntry("file_name_template", "%{trackartist} - %{number} - %{title}"));
         audioConfig->albumNameLineEdit->setText(cg.readEntry("album_name_template", "%{albumartist} - %{albumtitle}"));
-        audioConfig->fileLocationGroupBox->setChecked(cg.readEntry("show_file_location", false));
+        audioConfig->fileLocationCheckBox->setChecked(cg.readEntry("show_file_location", false));
         audioConfig->fileLocationLineEdit->setText(cg.readEntry("file_location_template", QString()));
         audioConfig->kcfg_replaceInput->setText(cg.readEntry("regexp_search"));
         audioConfig->kcfg_replaceOutput->setText(cg.readEntry("regexp_replace"));
@@ -208,6 +212,8 @@ void KAudiocdModule::load()
     for (int i = 0; i < encoderSettings.size(); ++i) {
         encoderSettings.at(i)->updateWidgets();
     }
+
+    audioConfig->fileLocationVerticalWidget->setEnabled(audioConfig->fileLocationCheckBox->isChecked());
 }
 
 void KAudiocdModule::slotModuleChanged()
